@@ -47,13 +47,25 @@ namespace MagickLib
 
 //
 // Provide appropriate DLL imports/exports for Visual C++,
-// Borland C++Builder and MinGW builds
+// Borland C++Builder and MinGW builds.
 //
 #if defined(WIN32) && !defined(__CYGWIN__) && !defined(__MINGW32__)
 # define MagickCplusPlusDLLSupported
 #endif
 #if defined(MagickCplusPlusDLLSupported)
-#  if defined(_MT) && defined(_DLL) && !defined(_LIB)
+#  if defined(_MT) && defined(_DLL) && !defined(_LIB) && !defined(STATIC_MAGICK)
+//
+// In a native Windows build, the following defines are used:
+//
+//   _MT         = Multithreaded
+//   _DLL        = Using code is part of a DLL
+//   _LIB        = Using code is being built as a library.
+//   _MAGICKMOD_ = Build uses loadable modules (Magick++ does not care about this)
+//
+// In the case where GraphicsMagick is built as a static library but the
+// using code is dynamic, STATIC_MAGICK may be defined in the project to
+// override triggering dynamic library behavior.
+//
 #    define MagickDLLBuild
 #    if defined(_VISUALC_)
 #      pragma warning( disable: 4273 )      /* Disable the stupid dll linkage warnings */
@@ -217,6 +229,7 @@ namespace Magick
   using MagickLib::UndefinedEndian;
   using MagickLib::LSBEndian;
   using MagickLib::MSBEndian;
+  using MagickLib::NativeEndian;
 
   // Fill rules
   using MagickLib::FillRule;
@@ -345,6 +358,10 @@ namespace Magick
   using MagickLib::NegateQuantumOp;
   using MagickLib::GammaQuantumOp;
   using MagickLib::DepthQuantumOp;
+  using MagickLib::LogQuantumOp;
+  using MagickLib::MaxQuantumOp;
+  using MagickLib::MinQuantumOp;
+  using MagickLib::PowQuantumOp;
   using MagickLib::QuantumOperator;
 
   // Preview types.  Not currently used by Magick++
@@ -466,10 +483,12 @@ namespace Magick
 
   // Resource types
   using MagickLib::ResourceType;
-  using MagickLib::FileResource;
-  using MagickLib::MemoryResource;
-  using MagickLib::MapResource;
   using MagickLib::DiskResource;
+  using MagickLib::FileResource;
+  using MagickLib::MapResource;
+  using MagickLib::MemoryResource;
+  using MagickLib::PixelsResource;
+  using MagickLib::ThreadsResource;
 
 #if defined(MAGICK_IMPLEMENTATION)
   //
@@ -483,10 +502,12 @@ namespace Magick
   using MagickLib::AdaptiveThresholdImage;
   using MagickLib::AddDefinitions;
   using MagickLib::AddNoiseImage;
+  using MagickLib::AddNoiseImageChannel;
   using MagickLib::AffineMatrix;
   using MagickLib::AffineTransformImage;
   using MagickLib::AllocateImage;
   using MagickLib::AnnotateImage;
+  using MagickLib::AreaValue;
   using MagickLib::AspectValue;
   using MagickLib::Base64Decode;
   using MagickLib::Base64Encode;
@@ -495,10 +516,12 @@ namespace Magick
   using MagickLib::BlobToImage;
   using MagickLib::BlobWarning;
   using MagickLib::BlurImage;
+  using MagickLib::BlurImageChannel;
   using MagickLib::BorderImage;
   using MagickLib::CacheError;
   using MagickLib::CacheFatalError;
   using MagickLib::CacheWarning;
+  using MagickLib::CdlImage;
   using MagickLib::ChannelImage;
   using MagickLib::CharcoalImage;
   using MagickLib::ChopImage;
@@ -512,6 +535,7 @@ namespace Magick
   using MagickLib::CoderWarning;
   using MagickLib::ColorFloodfillImage;
   using MagickLib::ColorizeImage;
+  using MagickLib::ColorMatrixImage;
   using MagickLib::CompositeImage;
   using MagickLib::ConfigureError;
   using MagickLib::ConfigureFatalError;
@@ -649,9 +673,10 @@ namespace Magick
   using MagickLib::GammaImage;
   using MagickLib::GammaImage;
   using MagickLib::GaussianBlurImage;
+  using MagickLib::GaussianBlurImageChannel;
   using MagickLib::GetBlobSize;
-  using MagickLib::GetCacheViewPixels;
   using MagickLib::GetCacheViewIndexes;
+  using MagickLib::GetCacheViewPixels;
   using MagickLib::GetColorTuple;
   using MagickLib::GetDrawInfo;
   using MagickLib::GetExceptionInfo;
@@ -677,6 +702,7 @@ namespace Magick
   using MagickLib::GetTypeMetrics;
   using MagickLib::GlobExpression;
   using MagickLib::GreaterValue;
+  using MagickLib::HaldClutImage;
   using MagickLib::HSLTransform;
   using MagickLib::HeightValue;
   using MagickLib::IdentityAffine;
@@ -709,6 +735,7 @@ namespace Magick
   using MagickLib::MatteFloodfillImage;
   using MagickLib::MedianFilterImage;
   using MagickLib::MinifyImage;
+  using MagickLib::MinimumValue;
   using MagickLib::MissingDelegateError;
   using MagickLib::MissingDelegateFatalError;
   using MagickLib::MissingDelegateWarning;
@@ -720,6 +747,7 @@ namespace Magick
   using MagickLib::MonitorFatalError;
   using MagickLib::MonitorWarning;
   using MagickLib::MontageInfo;
+  using MagickLib::MotionBlurImage;
   using MagickLib::NegateImage;
   using MagickLib::NoValue;
   using MagickLib::NoiseType;
@@ -745,6 +773,7 @@ namespace Magick
   using MagickLib::QueryColorDatabase;
   using MagickLib::RGBTransformImage;
   using MagickLib::RaiseImage;
+  using MagickLib::RandomChannelThresholdImage;
   using MagickLib::ReadImage;
   using MagickLib::RectangleInfo;
   using MagickLib::RectangleInfo;
@@ -782,6 +811,7 @@ namespace Magick
   using MagickLib::SetMagickResourceLimit;
   using MagickLib::ShadeImage;
   using MagickLib::SharpenImage;
+  using MagickLib::SharpenImageChannel;
   using MagickLib::ShaveImage;
   using MagickLib::ShearImage;
   using MagickLib::SignatureImage;
@@ -811,6 +841,7 @@ namespace Magick
   using MagickLib::UndefinedRegistryType;
   using MagickLib::UnregisterMagickInfo;
   using MagickLib::UnsharpMaskImage;
+  using MagickLib::UnsharpMaskImageChannel;
   using MagickLib::ViewInfo;
   using MagickLib::WaveImage;
   using MagickLib::WidthValue;
@@ -824,14 +855,6 @@ namespace Magick
   using MagickLib::YValue;
   using MagickLib::ZoomImage;
 
-  using MagickLib::AddNoiseImageChannel;
-  using MagickLib::BlurImageChannel;
-  using MagickLib::GaussianBlurImageChannel;
-  using MagickLib::MotionBlurImage;
-  using MagickLib::RandomChannelThresholdImage;
-  using MagickLib::SharpenImageChannel;
-  using MagickLib::UnsharpMaskImageChannel;
-
 
 #endif // MAGICK_IMPLEMENTATION
 
